@@ -37,10 +37,10 @@
 #include <tqregexp.h>
 
 // KDE includes
-#include <kapplication.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdeio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdelocale.h>
 
 // Own includes
 #include "ProgressDialog.h"
@@ -49,7 +49,7 @@
 #include "pluginloader.h"
 #include "kmylistview.h"
 
-using namespace KIO;
+using namespace TDEIO;
 
 BatchRenamer::BatchRenamer()
     : m_index( 0 )
@@ -493,7 +493,7 @@ void BatchRenamer::findNumberAppendix( TQString & text, int pos, int* start, int
     
     if( text[pos] == '{' && (end = text.find( "}", pos )) > -1)
     {
-        //qDebug("Found an appendix:" + appendix );
+        //tqDebug("Found an appendix:" + appendix );
         appendix = text.mid( pos + 1, end - pos - 1);
         text.remove( pos, end - pos + 1 );
        
@@ -848,7 +848,7 @@ void BatchRenamer::parseSubdirs( data* f )
             url.addPath( unEscape( d ) );
             if( !NetAccess::exists( url ) && !NetAccess::mkdir( url ) )
                 // TODO: GUI bug report
-                qDebug("Can't create %s", url.prettyURL().latin1() ); 
+                tqDebug("Can't create %s", url.prettyURL().latin1() ); 
 
             f->dst.url.addPath( d );
             f->dst.directory.append( d + "/" );
