@@ -38,22 +38,22 @@
 
 // KDE includes
 #include <dcopclient.h>
-#include <kaboutapplication.h>
-#include <kapplication.h>
-#include <kaction.h>
-#include <kcmdlineargs.h>
+#include <tdeaboutapplication.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
+#include <tdecmdlineargs.h>
 #include <kdirselectdialog.h>
-#include <kfiledialog.h>
-#include <kfileitem.h>
+#include <tdefiledialog.h>
+#include <tdefileitem.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kmenubar.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdemenubar.h>
+#include <tdepopupmenu.h>
 #include <kurlrequester.h>
-#include <ktempfile.h> 
-#include <klocale.h>
-#include <kio/netaccess.h>
+#include <tdetempfile.h> 
+#include <tdelocale.h>
+#include <tdeio/netaccess.h>
 
 // QT includes
 #include <tqbuttongroup.h>
@@ -165,7 +165,7 @@ void KRenameImpl::setup( bool wizardmode )
     // Load Configuration
     loadConfig();
     page_1->setEnabled( true );
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
         
     filename->setText( "$" );   // no i18n() ! ;)
     extemplate->setText( "$" );
@@ -184,7 +184,7 @@ const TQString KRenameImpl::title( int index ) const
 
 void KRenameImpl::parseCommandline()
 {
-    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
     QCStringList optlist = args->getOptionList ( "r" );
     for (QCStringList::ConstIterator it=optlist.begin(); it!=optlist.end(); ++it)
@@ -293,23 +293,23 @@ void KRenameImpl::parseCommandline()
 
 void KRenameImpl::setupActions()
 {
-    KActionCollection* actionCollection = new KActionCollection( this );
+    TDEActionCollection* actionCollection = new TDEActionCollection( this );
 
-    KPopupMenu* mnuExtra = new KPopupMenu( parent );
-    KPopupMenu* mnuSettings = new KPopupMenu( parent );
+    TDEPopupMenu* mnuExtra = new TDEPopupMenu( parent );
+    TDEPopupMenu* mnuSettings = new TDEPopupMenu( parent );
     KHelpMenu* mnuHelp = new KHelpMenu( parent );
 
     menuBar->insertItem( i18n("E&xtras"), mnuExtra );
     mnuExtra->insertItem( i18n("&Profiles..."), this, TQT_SLOT( manageProfiles() ) );
     mnuExtra->insertSeparator();
-    mnuExtra->insertItem( SmallIcon("undo"), i18n("&Undo Old Renaming Action..."), this, TQT_SLOT( undo() ) );
+    mnuExtra->insertItem( SmallIcon("edit-undo"), i18n("&Undo Old Renaming Action..."), this, TQT_SLOT( undo() ) );
     menuBar->insertItem( i18n("&Settings"), mnuSettings );
     menuBar->insertSeparator();
     menuBar->insertItem( i18n("&Help"), mnuHelp->menu() );
 
-    KAction* prefAct = KStdAction::preferences( this, TQT_SLOT(preferences()), actionCollection );
-    loadPlugins = new KAction( i18n("&Load KDE file plugins"), 0, this, TQT_SLOT( loadFilePlugins() ), actionCollection );
-    KAction* reloadAct = new KAction( i18n("&Reload Plugin Data"), 0, this, TQT_SLOT( reloadFilePluginData() ), actionCollection );
+    TDEAction* prefAct = KStdAction::preferences( this, TQT_SLOT(preferences()), actionCollection );
+    loadPlugins = new TDEAction( i18n("&Load TDE file plugins"), 0, this, TQT_SLOT( loadFilePlugins() ), actionCollection );
+    TDEAction* reloadAct = new TDEAction( i18n("&Reload Plugin Data"), 0, this, TQT_SLOT( reloadFilePluginData() ), actionCollection );
     
     prefAct->plug( mnuSettings );
     mnuSettings->insertSeparator();
@@ -567,7 +567,7 @@ void KRenameImpl::setupFileTab1()
     comboExtension = new KComboBox( false, tab );
 
     buttonReplace = new KPushButton( i18n("Find &and Replace..."), tab );
-    buttonReplace->setIconSet( SmallIconSet("find") );
+    buttonReplace->setIconSet( SmallIconSet("edit-find") );
 
     buttonNumber = new KPushButton( i18n("&Numbering..."), tab );
     buttonCoord = new KPushButton( i18n("&Insert Part of Filename..."), tab );
@@ -706,7 +706,7 @@ void KRenameImpl::setupFileTab2()
     spinNull->setRange( 1, 100, 1, false );
     
     buttonEasyReplace = new KPushButton( i18n("&Find and Replace..."), rightBox );
-    buttonEasyReplace->setIconSet( SmallIconSet("find") );
+    buttonEasyReplace->setIconSet( SmallIconSet("edit-find") );
     
     layout->addWidget( vgroup1 );
     layout->addWidget( rightBox );
@@ -1011,7 +1011,7 @@ void KRenameImpl::start()
     filename->saveSettings();
     extemplate->saveSettings();
 
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
     config->setGroup("FileExtension");
     config->writeEntry("FileExtensionCombo", comboExtension->currentItem() );
 
@@ -1162,7 +1162,7 @@ bool KRenameImpl::setupBatchRenamer( BatchRenamer* b, bool preview )
         if( url.right(1) != "/" )
             url.append( "/" );
         
-        if( !KIO::NetAccess::exists( KURL( url ) ) )
+        if( !TDEIO::NetAccess::exists( KURL( url ) ) )
         {
             int m = KMessageBox::warningContinueCancel( parent, i18n("The directory %1 does not exist. "
             "KRename will create it for you.").arg( url ) );
@@ -1172,9 +1172,9 @@ bool KRenameImpl::setupBatchRenamer( BatchRenamer* b, bool preview )
             int i = 0;
             TQString d = "/";
             while( (d += url.section( "/", i, i, TQString::SectionSkipEmpty )) && ! d.isEmpty() ) { // asignment here!
-                if( !KIO::NetAccess::exists( d ) && !KIO::NetAccess::mkdir( d ) )
+                if( !TDEIO::NetAccess::exists( d ) && !TDEIO::NetAccess::mkdir( d ) )
                 {
-                    qDebug( "Can't create %s", d.latin1() );
+                    tqDebug( "Can't create %s", d.latin1() );
                     break;
                 }
                 d.append( "/" );
@@ -1244,9 +1244,9 @@ void KRenameImpl::updatePreview()
     BatchRenamer b;
     if( setupBatchRenamer( &b, true ) )
     {
-        KApplication::setOverrideCursor( TQt::WaitCursor );
+        TDEApplication::setOverrideCursor( TQt::WaitCursor );
         b.createPreview( preview );
-        KApplication::restoreOverrideCursor();
+        TDEApplication::restoreOverrideCursor();
     }
     preview->horizontalScrollBar()->setValue( h );
     preview->verticalScrollBar()->setValue( v );
@@ -1254,7 +1254,7 @@ void KRenameImpl::updatePreview()
 
 void KRenameImpl::loadConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     config->setGroup("HistSize");
     m_hist = config->readNumEntry("HistoryItems", 10 );
@@ -1307,7 +1307,7 @@ void KRenameImpl::loadConfig()
 
     //parent->show();
     page_1->setEnabled( false );
-    KApplication::setOverrideCursor( TQt::WaitCursor );
+    TDEApplication::setOverrideCursor( TQt::WaitCursor );
     plugin->loadPlugins( m_loadplugins );
     setupTab1();
     config->setGroup("GUISettings");
@@ -1320,7 +1320,7 @@ void KRenameImpl::loadConfig()
 
 void KRenameImpl::saveConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     config->setGroup("HistSize");
     config->writeEntry("HistoryItems", m_hist );
@@ -1359,20 +1359,20 @@ void KRenameImpl::replace()
 
 void KRenameImpl::toggleImagePreview()
 {
-    KApplication::setOverrideCursor( TQt::waitCursor );
+    TDEApplication::setOverrideCursor( TQt::waitCursor );
     fileList->setPreview( checkPreview->isChecked() );
     checkName->setEnabled( checkPreview->isChecked() );
     if( !checkPreview->isChecked() )
         checkName->setChecked( true );
     fileList->setName( checkName->isChecked() );
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 }
 
 void KRenameImpl::toggleName()
 {
-    KApplication::setOverrideCursor( TQt::waitCursor );
+    TDEApplication::setOverrideCursor( TQt::waitCursor );
     fileList->setName( checkName->isChecked() );
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 }
 
 void KRenameImpl::preferences()
@@ -1606,7 +1606,7 @@ void KRenameImpl::changeNumbers()
 
 void KRenameImpl::about()
 {
-    KAboutApplication * d = new KAboutApplication( kapp->aboutData(), parent );
+    TDEAboutApplication * d = new TDEAboutApplication( kapp->aboutData(), parent );
     d->show();
 }
 
@@ -1659,7 +1659,7 @@ void KRenameImpl::changeParent( TQWidget* p, KMenuBar* m, TQPushButton* finish,
 
 TQWidget* KRenameImpl::launch( TQRect rect, const KURL::List & list, KRenameImpl* impl, bool loadprofile )
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("GUISettings");
     bool firststart = config->readBoolEntry( "firststart", true );
     bool wizardmode = config->readBoolEntry( "GUIWizardMode", false );
@@ -1786,9 +1786,9 @@ void KRenameImpl::setCounterStart( int index )
 
 void KRenameImpl::loadFilePlugins()
 {
-    KApplication::setOverrideCursor( TQt::WaitCursor );        
+    TDEApplication::setOverrideCursor( TQt::WaitCursor );        
     plugin->loadPlugins( true );
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
     pluginHelpChanged();
     
     enableControls();
