@@ -21,14 +21,14 @@
 #include "pluginloader.h"
 #include "kmylistbox.h"
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
 #include <kinputdialog.h> 
-#include <klistbox.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelistbox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
@@ -96,7 +96,7 @@ ProfileManager::ProfileManager( KRenameImpl* krename )
 const TQString ProfileManager::readProfilePath( const TQString & name )
 {
     TQString path;
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     
     conf->setGroup( "Profiles" );
     path = conf->readEntry( name, TQString() );
@@ -115,7 +115,7 @@ const TQString ProfileManager::getProfilePath( const TQString & name )
 
     TQString path = locateLocal( "data", TQString( "krename/%1.xml" ).arg( name ) );
     
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     
     conf->setGroup( "ProfilesHeader" );
     list = conf->readListEntry( "list" );
@@ -137,7 +137,7 @@ void ProfileManager::writeXML( const TQString & name )
     
     if( !file.open( IO_WriteOnly ) )
     {
-        qDebug("Cannot write to: %s", path.latin1() );
+        tqDebug("Cannot write to: %s", path.latin1() );
         return;
     }
     
@@ -211,7 +211,7 @@ bool ProfileManager::loadXML( const TQString & path )
     
     if( !file.open( IO_ReadOnly ) )
     {
-        qDebug("Cannot read from: %s", path.latin1() );
+        tqDebug("Cannot read from: %s", path.latin1() );
         return false;
     }
 
@@ -364,7 +364,7 @@ const TQValueList<int> ProfileManager::stringToList( const TQString & data )
 
 bool ProfileManager::hasDefaultProfile()
 {
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     conf->setGroup( "ProfilesHeader" );
 
     TQString def = conf->readEntry( "defprofile", TQString() );
@@ -374,7 +374,7 @@ bool ProfileManager::hasDefaultProfile()
 
 void ProfileManager::loadDefaultProfile( KRenameImpl* krename )
 {
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     conf->setGroup( "ProfilesHeader" );
 
     TQString def = conf->readEntry( "defprofile", TQString() );
@@ -400,7 +400,7 @@ ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *parent, const char *name)
     TQHBoxLayout* layout = new TQHBoxLayout( plainPage(), 6, 6 );
     TQVBoxLayout* button = new TQVBoxLayout( 0, 6, 6 );
     
-    profiles = new KListBox( plainPage() );
+    profiles = new TDEListBox( plainPage() );
     profiles->insertItem( new ProfileListBoxText( PROFILE_WIZARD_NAME ), PROFILE_WIZARD_INDEX );
     profiles->insertItem( new ProfileListBoxText( PROFILE_TABBED_NAME ), PROFILE_TABBED_INDEX );
     
@@ -409,8 +409,8 @@ ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *parent, const char *name)
     deleteProfile = new KPushButton( i18n("&Delete Profile"), plainPage() );
     checkDefault = new TQCheckBox( i18n("&Use as default profile on startup"), plainPage() );
 
-    createProfile->setIconSet( SmallIconSet( "filesaveas") );
-    loadProfile->setIconSet( SmallIconSet( "fileopen" ) );
+    createProfile->setIconSet( SmallIconSet( "document-save-as") );
+    loadProfile->setIconSet( SmallIconSet( "document-open" ) );
     deleteProfile->setIconSet( SmallIconSet( "edittrash" ) );
     
     TQSpacerItem* spacer = new TQSpacerItem( 20, 20, TQSizePolicy::Expanding, TQSizePolicy::Expanding );
@@ -437,7 +437,7 @@ ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *parent, const char *name)
     connect( checkDefault, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSetDefault() ) );
     connect( this, TQT_SIGNAL( hidden() ), this, TQT_SLOT( slotHidden() ) );
 
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     conf->setGroup( "ProfilesHeader" );
     ProfileListBoxText* item;
 
@@ -565,7 +565,7 @@ void ProfileDlg::slotDeleteProfile()
         if( item )
             delete item;
         
-        KConfig* conf = kapp->config();
+        TDEConfig* conf = kapp->config();
         
         conf->setGroup( "ProfilesHeader" );
         TQStringList list = conf->readListEntry( "list" );
@@ -580,7 +580,7 @@ void ProfileDlg::slotDeleteProfile()
 void ProfileDlg::slotHidden()
 {
     int i;
-    KConfig* conf = kapp->config();
+    TDEConfig* conf = kapp->config();
     TQString def = TQString();
     ProfileListBoxText* item;
 
